==> markuplint-4.9.2.tgz: package/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

## [4.9.2](https://github.com/markuplint/markuplint/compare/markuplint@4.9.1...markuplint@4.9.2) (2024-06-25)


### Bug Fixes

* **markuplint:** ensure `--config` option correctly handles absolute paths ([fd36c1a](https://github.com/markuplint/markuplint/commit/fd36c1a4475f71d8b1e83212a60639c7361cd702))





## [4.9.1](https://github.com/markuplint/markuplint/compare/markuplint@4.9.0...markuplint@4.9.1) (2024-06-09)

### Bug Fixes

- fix to export type files ([eff4bbf](https://github.com/markuplint/markuplint/commit/eff4bbfd127574809dc5e15d7cafe87699758ee0))

# [4.9.0](https://github.com/markuplint/markuplint/compare/markuplint@4.8.1...markuplint@4.9.0) (2024-05-28)

### Features

- **file-resolver:** add `resolve-pretenders` function ([68ba7f5](https://github.com/markuplint/markuplint/commit/68ba7f5acaba13484172bca3ea5f60e0bf3044ef))

## [4.8.1](https://github.com/markuplint/markuplint/compare/markuplint@4.8.0...markuplint@4.8.1) (2024-05-12)

**Note:** Version bump only for package markuplint

# [4.8.0](https://github.com/markuplint/markuplint/compare/markuplint@4.8.0-alpha.0...markuplint@4.8.0) (2024-05-04)

**Note:** Version bump only for package markuplint

# [4.8.0-alpha.0](https://github.com/markuplint/markuplint/compare/markuplint@4.7.0...markuplint@4.8.0-alpha.0) (2024-05-04)

### Features

- **rules:** apply `no-ambiguous-navigable-target-names` to build-in rules ([93d34f0](https://github.com/markuplint/markuplint/commit/93d34f0ead2624107a5b6f315af0c8bbd4f1e1ec))
- **rules:** apply `table-row-column-alignment` to build-in rules ([85de609](https://github.com/markuplint/markuplint/commit/85de6098813cd7c3167099f9e7e6250ca8324539))

==> markuplint-4.9.3.tgz: package/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

## [4.9.3](https://github.com/markuplint/markuplint/compare/markuplint@4.9.2...markuplint@4.9.3) (2024-09-02)

**Note:** Version bump only for package markuplint





## [4.9.2](https://github.com/markuplint/markuplint/compare/markuplint@4.9.1...markuplint@4.9.2) (2024-06-25)

### Bug Fixes

- **markuplint:** ensure `--config` option correctly handles absolute paths ([fd36c1a](https://github.com/markuplint/markuplint/commit/fd36c1a4475f71d8b1e83212a60639c7361cd702))

## [4.9.1](https://github.com/markuplint/markuplint/compare/markuplint@4.9.0...markuplint@4.9.1) (2024-06-09)

### Bug Fixes

- fix to export type files ([eff4bbf](https://github.com/markuplint/markuplint/commit/eff4bbfd127574809dc5e15d7cafe87699758ee0))

# [4.9.0](https://github.com/markuplint/markuplint/compare/markuplint@4.8.1...markuplint@4.9.0) (2024-05-28)

### Features

- **file-resolver:** add `resolve-pretenders` function ([68ba7f5](https://github.com/markuplint/markuplint/commit/68ba7f5acaba13484172bca3ea5f60e0bf3044ef))

## [4.8.1](https://github.com/markuplint/markuplint/compare/markuplint@4.8.0...markuplint@4.8.1) (2024-05-12)

**Note:** Version bump only for package markuplint

# [4.8.0](https://github.com/markuplint/markuplint/compare/markuplint@4.8.0-alpha.0...markuplint@4.8.0) (2024-05-04)

**Note:** Version bump only for package markuplint

# [4.8.0-alpha.0](https://github.com/markuplint/markuplint/compare/markuplint@4.7.0...markuplint@4.8.0-alpha.0) (2024-05-04)

### Features

- **rules:** apply `no-ambiguous-navigable-target-names` to build-in rules ([93d34f0](https://github.com/markuplint/markuplint/commit/93d34f0ead2624107a5b6f315af0c8bbd4f1e1ec))
- **rules:** apply `table-row-column-alignment` to build-in rules ([85de609](https://github.com/markuplint/markuplint/commit/85de6098813cd7c3167099f9e7e6250ca8324539))
